"use client";

import React, { memo, useState } from "react";
import { ChevronDownIcon, ChevronUpIcon } from "@chakra-ui/icons";
import { Avatar, Box, Button, Fade, Flex, Text, Image } from "@chakra-ui/react";
import { useRouter } from "next/navigation";
import moment from "moment";
import { ConsumerInterface } from "../../consumers/type/consumer";
import Link from "next/link";

export interface ConsumerCardProps {
  consumer: ConsumerInterface;
  isOpen: boolean;
  onToggle: () => void;
  fetch: () => void;
}

const Card: React.FC<ConsumerCardProps> = ({
  consumer,
  isOpen,
  onToggle,
  fetch,
}) => {
  const router = useRouter();

  const handleUpload = async () => {
    router.push(`/officer/dc/draft?id=${consumer?.id}`);
  };

  return (
    <Box border="1px" p={3} rounded="20px" mt="30px">
      <Flex gap={2} alignItems="center" w="100%">
        <Flex
          flexDirection="row"
          alignItems="center"
          w="100%"
          gap={2}
          cursor="pointer"
        >
          <Avatar name={consumer?.case?.name} size="sm" />

          <Text
            fontSize="lg"
            fontWeight="bold"
            textTransform="uppercase"
            onClick={onToggle}
          >
            {consumer?.case?.name} | &nbsp; {consumer?.case?.contract} |{" "}
            {consumer?.case?.contract_account} | CD:{" "}
            {consumer?.case?.cycle_day?.cycle_day} | MRU: {consumer?.case?.mru}
          </Text>

          <Box ms="auto" onClick={onToggle}>
            {isOpen ? (
              <ChevronUpIcon width="20px" height="20px" />
            ) : (
              <ChevronDownIcon width="20px" height="20px" />
            )}
          </Box>
        </Flex>
      </Flex>
      {isOpen && (
        <Fade in>
          <Box py="1" mt={3} px={0} rounded="md">
            <Flex
              rowGap={1}
              alignItems="center"
              flexWrap="wrap"
              justifyContent="space-between"
            >
              <Box width="50%">
                <Text fontSize="sm" fontWeight="bold">
                  Contact Person: &nbsp;
                  <Text as="span" fontWeight="normal">
                    {consumer?.contact_person}
                  </Text>
                </Text>
              </Box>
              <Box width="50%">
                <Text fontSize="sm" fontWeight="bold">
                  Mobile No: &nbsp;
                  <Text as="span" fontWeight="normal">
                    {consumer?.mobile_no}
                  </Text>
                </Text>
              </Box>
              <Box width="50%">
                <Text fontSize="sm" fontWeight="bold">
                  Paid Amount: &nbsp;
                  <Text as="span" fontWeight="normal">
                    {consumer?.paid_amount}
                  </Text>
                </Text>
              </Box>
              <Box width="50%">
                <Text fontSize="sm" fontWeight="bold">
                  DC Request: &nbsp;
                  <Text as="span" fontWeight="normal">
                    {consumer?.dc_request == 1 ? "Yes" : "No"}
                  </Text>
                </Text>
              </Box>
              <Box width="50%">
                <Text fontSize="sm" fontWeight="bold">
                  Meter/ UnMeter: &nbsp;
                  <Text as="span" fontWeight="normal">
                    {consumer?.meter_un_meter == 1 ? "Yes" : "No"}
                  </Text>
                </Text>
              </Box>
              {consumer?.meter_un_meter == 1 && (
                <>
                  <Box width="50%">
                    <Text fontSize="sm" fontWeight="bold">
                      Meter Reading: &nbsp;
                      <Text as="span" fontWeight="normal">
                        {consumer?.meter_reading}
                      </Text>
                    </Text>
                  </Box>
                  <Box width="50%">
                    <Text fontSize="sm" fontWeight="bold">
                      Meter No: &nbsp;
                      <Text as="span" fontWeight="normal">
                        {consumer?.meter_no}
                      </Text>
                    </Text>
                  </Box>
                </>
              )}
              {consumer?.meter_un_meter == 0 && (
                <Box width="50%">
                  <Text fontSize="sm" fontWeight="bold">
                    Reason for Un meter: &nbsp;
                    <Text as="span" fontWeight="normal">
                      {consumer?.un_meter_reason}
                    </Text>
                  </Text>
                </Box>
              )}
              <Box width="50%">
                <Text fontSize="sm" fontWeight="bold">
                  Remarks: &nbsp;
                  <Text as="span" fontWeight="normal">
                    {consumer?.remarks}
                  </Text>
                </Text>
              </Box>
              <Box width="50%">
                <Text fontSize="sm" fontWeight="bold">
                  Additional Remarks: &nbsp;
                  <Text as="span" fontWeight="normal">
                    {consumer?.additional_remarks}
                  </Text>
                </Text>
              </Box>

              <Box width="50%">
                <Text fontSize="sm" fontWeight="bold">
                  Created At: &nbsp;
                  <Text as="span" fontWeight="normal">
                    {moment(consumer?.created_at).fromNow()}
                  </Text>
                </Text>
              </Box>
              <Box width="50%">
                <Text fontSize="sm" fontWeight="bold">
                  Updated At: &nbsp;
                  <Text as="span" fontWeight="normal">
                    {moment(consumer?.updated_at).fromNow()}
                  </Text>
                </Text>
              </Box>
              {consumer?.files?.length > 0 && (
                <Box width="100%">
                  <Text fontSize="sm" fontWeight="bold">
                    Attachments: &nbsp;
                    {consumer?.files?.map(
                      (consumerImage: any, index: number) => (
                        <Link
                          key={index}
                          href={consumerImage || "#"}
                          target="_blank"
                        >
                          <Image
                            key={index}
                            src={consumerImage}
                            alt="attachment"
                            boxSize="200px"
                            mt="10px"
                            objectFit="contain"
                          />
                        </Link>
                      )
                    )}
                  </Text>
                </Box>
              )}
            </Flex>
          </Box>
        </Fade>
      )}

      {consumer?.offline && (
        <Flex columnGap={1} alignItems="center" mt="6">
          <Button
            onClick={handleUpload}
            size="sm"
            px="3"
          >
            Upload
          </Button>
        </Flex>
      )}
    </Box>
  );
};

export default memo(Card);
